unit MessageDict;

interface

uses
  Messages, Controls, Classes, SysUtils;

type

  EMessageDictError = class(Exception);
  TMessageName = String[24];
  TMessageDict = class(TObject)
  private
    MsgList:    TList;
    NameList:   TStringList;
    procedure InitializeDict;
  public
    constructor Create;
    destructor Destroy; override;
    function MessageName(Number: Cardinal): TMessageName;
  end;

implementation

constructor TMessageDict.Create;
begin
  inherited Create;
  MsgList := TList.Create;
  MsgList.Capacity := 435;
  NameList := TStringList.Create;
  NameList.Capacity := 435;
  InitializeDict;
end;

destructor TMessageDict.Destroy;
begin
  MsgList.Free;
  NameList.Free;
  inherited Destroy;
end;

function TMessageDict.MessageName(Number: Cardinal): TMessageName;
var
  L: Integer;
  H: Integer;
  I: Integer;
  C: Integer;
  Found: Boolean;
begin
  Found := False;
  L := 0;
  H := MsgList.Count - 1;
  while L <= H do
  begin
    I := (L + H) shr 1;
    C := LongRec(MsgList[I]).Hi - Number;
    if C < 0 then
      L := I + 1
    else
    begin
      H := I - 1;
      if C = 0 then
        Found := True;
    end;
  end;
  if Found then
    Result := NameList[LongRec(MsgList[L]).Lo]
  else
    Result := '$' + IntToHex(Number, 8) + StringOfChar(' ', 11);
end;

function SortMsgListProc(Item1: Pointer; Item2: Pointer): Integer;
begin
  Result := LongRec(Item1).Hi - LongRec(Item2).Hi;
end;

procedure TMessageDict.InitializeDict;
var
  I:  Integer;

  procedure AddMsg(const Name: String; Number: Word);
  var
    L:    LongRec;
  begin
    Inc(I);
    L.Hi := Number;
    L.Lo := I;
    MsgList.Add(Pointer(L));
    NameList.Add(Name);
  end;

begin
  I := -1;
  AddMsg('WM_NULL             ', $0000);
  AddMsg('WM_CREATE           ', $0001);
  AddMsg('WM_DESTROY          ', $0002);
  AddMsg('WM_MOVE             ', $0003);
  AddMsg('WM_SIZE             ', $0005);
  AddMsg('WM_ACTIVATE         ', $0006);
  AddMsg('WM_SETFOCUS         ', $0007);
  AddMsg('WM_KILLFOCUS        ', $0008);
  AddMsg('WM_ENABLE           ', $000A);
  AddMsg('WM_SETREDRAW        ', $000B);
  AddMsg('WM_SETTEXT          ', $000C);
  AddMsg('WM_GETTEXT          ', $000D);
  AddMsg('WM_GETTEXTLENGTH    ', $000E);
  AddMsg('WM_PAINT            ', $000F);
  AddMsg('WM_CLOSE            ', $0010);
  AddMsg('WM_QUERYENDSESSION  ', $0011);
  AddMsg('WM_QUIT             ', $0012);
  AddMsg('WM_QUERYOPEN        ', $0013);
  AddMsg('WM_ERASEBKGND       ', $0014);
  AddMsg('WM_SYSCOLORCHANGE   ', $0015);
  AddMsg('WM_ENDSESSION       ', $0016);
  AddMsg('WM_SYSTEMERROR      ', $0017);
  AddMsg('WM_SHOWWINDOW       ', $0018);
  AddMsg('WM_CTLCOLOR         ', $0019);
  AddMsg('WM_SETTINGCHANGE    ', $001A);
  AddMsg('WM_DEVMODECHANGE    ', $001B);
  AddMsg('WM_ACTIVATEAPP      ', $001C);
  AddMsg('WM_FONTCHANGE       ', $001D);
  AddMsg('WM_TIMECHANGE       ', $001E);
  AddMsg('WM_CANCELMODE       ', $001F);
  AddMsg('WM_SETCURSOR        ', $0020);
  AddMsg('WM_MOUSEACTIVATE    ', $0021);
  AddMsg('WM_CHILDACTIVATE    ', $0022);
  AddMsg('WM_QUEUESYNC        ', $0023);
  AddMsg('WM_GETMINMAXINFO    ', $0024);
  AddMsg('WM_PAINTICON        ', $0026);
  AddMsg('WM_ICONERASEBKGND   ', $0027);
  AddMsg('WM_NEXTDLGCTL       ', $0028);
  AddMsg('WM_SPOOLERSTATUS    ', $002A);
  AddMsg('WM_DRAWITEM         ', $002B);
  AddMsg('WM_MEASUREITEM      ', $002C);
  AddMsg('WM_DELETEITEM       ', $002D);
  AddMsg('WM_VKEYTOITEM       ', $002E);
  AddMsg('WM_CHARTOITEM       ', $002F);
  AddMsg('WM_SETFONT          ', $0030);
  AddMsg('WM_GETFONT          ', $0031);
  AddMsg('WM_SETHOTKEY        ', $0032);
  AddMsg('WM_GETHOTKEY        ', $0033);
  AddMsg('WM_QUERYDRAGICON    ', $0037);
  AddMsg('WM_COMPAREITEM      ', $0039);
  AddMsg('WM_GETOBJECT        ', $003D);
  AddMsg('WM_COMPACTING       ', $0041);
  AddMsg('WM_WINDOWPOSCHANGING ', $0046);
  AddMsg('WM_WINDOWPOSCHANGED ', $0047);
  AddMsg('WM_POWER            ', $0048);
  AddMsg('WM_COPYDATA         ', $004A);
  AddMsg('WM_CANCELJOURNAL    ', $004B);
  AddMsg('WM_NOTIFY           ', $004E);
  AddMsg('WM_INPUTLANGCHANGEREQUEST ', $0050);
  AddMsg('WM_INPUTLANGCHANGE  ', $0051);
  AddMsg('WM_TCARD            ', $0052);
  AddMsg('WM_HELP             ', $0053);
  AddMsg('WM_USERCHANGED      ', $0054);
  AddMsg('WM_NOTIFYFORMAT     ', $0055);
  AddMsg('WM_CONTEXTMENU      ', $007B);
  AddMsg('WM_STYLECHANGING    ', $007C);
  AddMsg('WM_STYLECHANGED     ', $007D);
  AddMsg('WM_DISPLAYCHANGE    ', $007E);
  AddMsg('WM_GETICON          ', $007F);
  AddMsg('WM_SETICON          ', $0080);
  AddMsg('WM_NCCREATE         ', $0081);
  AddMsg('WM_NCDESTROY        ', $0082);
  AddMsg('WM_NCCALCSIZE       ', $0083);
  AddMsg('WM_NCHITTEST        ', $0084);
  AddMsg('WM_NCPAINT          ', $0085);
  AddMsg('WM_NCACTIVATE       ', $0086);
  AddMsg('WM_GETDLGCODE       ', $0087);
  AddMsg('WM_NCMOUSEMOVE      ', $00A0);
  AddMsg('WM_NCLBUTTONDOWN    ', $00A1);
  AddMsg('WM_NCLBUTTONUP      ', $00A2);
  AddMsg('WM_NCLBUTTONDBLCLK  ', $00A3);
  AddMsg('WM_NCRBUTTONDOWN    ', $00A4);
  AddMsg('WM_NCRBUTTONUP      ', $00A5);
  AddMsg('WM_NCRBUTTONDBLCLK  ', $00A6);
  AddMsg('WM_NCMBUTTONDOWN    ', $00A7);
  AddMsg('WM_NCMBUTTONUP      ', $00A8);
  AddMsg('WM_NCMBUTTONDBLCLK  ', $00A9);
  AddMsg('WM_KEYDOWN          ', $0100);
  AddMsg('WM_KEYUP            ', $0101);
  AddMsg('WM_CHAR             ', $0102);
  AddMsg('WM_DEADCHAR         ', $0103);
  AddMsg('WM_SYSKEYDOWN       ', $0104);
  AddMsg('WM_SYSKEYUP         ', $0105);
  AddMsg('WM_SYSCHAR          ', $0106);
  AddMsg('WM_SYSDEADCHAR      ', $0107);
  AddMsg('WM_INITDIALOG       ', $0110);
  AddMsg('WM_COMMAND          ', $0111);
  AddMsg('WM_SYSCOMMAND       ', $0112);
  AddMsg('WM_TIMER            ', $0113);
  AddMsg('WM_HSCROLL          ', $0114);
  AddMsg('WM_VSCROLL          ', $0115);
  AddMsg('WM_INITMENU         ', $0116);
  AddMsg('WM_INITMENUPOPUP    ', $0117);
  AddMsg('WM_MENUSELECT       ', $011F);
  AddMsg('WM_MENUCHAR         ', $0120);
  AddMsg('WM_ENTERIDLE        ', $0121);
  AddMsg('WM_MENURBUTTONUP    ', $0122);
  AddMsg('WM_MENUDRAG         ', $0123);
  AddMsg('WM_MENUGETOBJECT    ', $0124);
  AddMsg('WM_UNINITMENUPOPUP  ', $0125);
  AddMsg('WM_MENUCOMMAND      ', $0126);
  AddMsg('WM_CTLCOLORMSGBOX   ', $0132);
  AddMsg('WM_CTLCOLOREDIT     ', $0133);
  AddMsg('WM_CTLCOLORLISTBOX  ', $0134);
  AddMsg('WM_CTLCOLORBTN      ', $0135);
  AddMsg('WM_CTLCOLORDLG      ', $0136);
  AddMsg('WM_CTLCOLORSCROLLBAR', $0137);
  AddMsg('WM_CTLCOLORSTATIC   ', $0138);
  AddMsg('WM_MOUSEMOVE        ', $0200);
  AddMsg('WM_LBUTTONDOWN      ', $0201);
  AddMsg('WM_LBUTTONUP        ', $0202);
  AddMsg('WM_LBUTTONDBLCLK    ', $0203);
  AddMsg('WM_RBUTTONDOWN      ', $0204);
  AddMsg('WM_RBUTTONUP        ', $0205);
  AddMsg('WM_RBUTTONDBLCLK    ', $0206);
  AddMsg('WM_MBUTTONDOWN      ', $0207);
  AddMsg('WM_MBUTTONUP        ', $0208);
  AddMsg('WM_MBUTTONDBLCLK    ', $0209);
  AddMsg('WM_MOUSEWHEEL       ', $020A);
  AddMsg('WM_PARENTNOTIFY     ', $0210);
  AddMsg('WM_ENTERMENULOOP    ', $0211);
  AddMsg('WM_EXITMENULOOP     ', $0212);
  AddMsg('WM_NEXTMENU         ', $0213);
  AddMsg('WM_SIZING           ', 532);
  AddMsg('WM_CAPTURECHANGED   ', 533);
  AddMsg('WM_MOVING           ', 534);
  AddMsg('WM_POWERBROADCAST   ', 536);
  AddMsg('WM_DEVICECHANGE     ', 537);
  AddMsg('WM_IME_STARTCOMPOSITION ', $010D);
  AddMsg('WM_IME_ENDCOMPOSITION ', $010E);
  AddMsg('WM_IME_COMPOSITION  ', $010F);
  AddMsg('WM_IME_SETCONTEXT   ', $0281);
  AddMsg('WM_IME_NOTIFY       ', $0282);
  AddMsg('WM_IME_CONTROL      ', $0283);
  AddMsg('WM_IME_COMPOSITIONFULL ', $0284);
  AddMsg('WM_IME_SELECT       ', $0285);
  AddMsg('WM_IME_CHAR         ', $0286);
  AddMsg('WM_IME_REQUEST      ', $0288);
  AddMsg('WM_IME_KEYDOWN      ', $0290);
  AddMsg('WM_IME_KEYUP        ', $0291);
  AddMsg('WM_MDICREATE        ', $0220);
  AddMsg('WM_MDIDESTROY       ', $0221);
  AddMsg('WM_MDIACTIVATE      ', $0222);
  AddMsg('WM_MDIRESTORE       ', $0223);
  AddMsg('WM_MDINEXT          ', $0224);
  AddMsg('WM_MDIMAXIMIZE      ', $0225);
  AddMsg('WM_MDITILE          ', $0226);
  AddMsg('WM_MDICASCADE       ', $0227);
  AddMsg('WM_MDIICONARRANGE   ', $0228);
  AddMsg('WM_MDIGETACTIVE     ', $0229);
  AddMsg('WM_MDISETMENU       ', $0230);
  AddMsg('WM_ENTERSIZEMOVE    ', $0231);
  AddMsg('WM_EXITSIZEMOVE     ', $0232);
  AddMsg('WM_DROPFILES        ', $0233);
  AddMsg('WM_MDIREFRESHMENU   ', $0234);
  AddMsg('WM_MOUSEHOVER       ', $02A1);
  AddMsg('WM_MOUSELEAVE       ', $02A3);
  AddMsg('WM_CUT              ', $0300);
  AddMsg('WM_COPY             ', $0301);
  AddMsg('WM_PASTE            ', $0302);
  AddMsg('WM_CLEAR            ', $0303);
  AddMsg('WM_UNDO             ', $0304);
  AddMsg('WM_RENDERFORMAT     ', $0305);
  AddMsg('WM_RENDERALLFORMATS ', $0306);
  AddMsg('WM_DESTROYCLIPBOARD ', $0307);
  AddMsg('WM_DRAWCLIPBOARD    ', $0308);
  AddMsg('WM_PAINTCLIPBOARD   ', $0309);
  AddMsg('WM_VSCROLLCLIPBOARD ', $030A);
  AddMsg('WM_SIZECLIPBOARD    ', $030B);
  AddMsg('WM_ASKCBFORMATNAME  ', $030C);
  AddMsg('WM_CHANGECBCHAIN    ', $030D);
  AddMsg('WM_HSCROLLCLIPBOARD ', $030E);
  AddMsg('WM_QUERYNEWPALETTE  ', $030F);
  AddMsg('WM_PALETTEISCHANGING', $0310);
  AddMsg('WM_PALETTECHANGED   ', $0311);
  AddMsg('WM_HOTKEY           ', $0312);
  AddMsg('WM_PRINT            ', 791);
  AddMsg('WM_PRINTCLIENT      ', 792);
  AddMsg('WM_HANDHELDFIRST    ', 856);
  AddMsg('WM_HANDHELDLAST     ', 863);
  AddMsg('WM_PENWINFIRST      ', $0380);
  AddMsg('WM_PENWINLAST       ', $038F);
  AddMsg('WM_COALESCE_FIRST   ', $0390);
  AddMsg('WM_COALESCE_LAST    ', $039F);
  AddMsg('WM_DDE_INITIATE     ', WM_DDE_FIRST + 0);
  AddMsg('WM_DDE_TERMINATE    ', WM_DDE_FIRST + 1);
  AddMsg('WM_DDE_ADVISE       ', WM_DDE_FIRST + 2);
  AddMsg('WM_DDE_UNADVISE     ', WM_DDE_FIRST + 3);
  AddMsg('WM_DDE_ACK          ', WM_DDE_FIRST + 4);
  AddMsg('WM_DDE_DATA         ', WM_DDE_FIRST + 5);
  AddMsg('WM_DDE_REQUEST      ', WM_DDE_FIRST + 6);
  AddMsg('WM_DDE_POKE         ', WM_DDE_FIRST + 7);
  AddMsg('WM_DDE_EXECUTE      ', WM_DDE_FIRST + 8);
  AddMsg('WM_APP              ', $8000);
  AddMsg('WM_USER             ', $0400);
  AddMsg('BM_GETCHECK         ', $00F0);
  AddMsg('BM_SETCHECK         ', $00F1);
  AddMsg('BM_GETSTATE         ', $00F2);
  AddMsg('BM_SETSTATE         ', $00F3);
  AddMsg('BM_SETSTYLE         ', $00F4);
  AddMsg('BM_CLICK            ', $00F5);
  AddMsg('BM_GETIMAGE         ', $00F6);
  AddMsg('BM_SETIMAGE         ', $00F7);
  AddMsg('LB_ADDSTRING        ', $0180);
  AddMsg('LB_INSERTSTRING     ', $0181);
  AddMsg('LB_DELETESTRING     ', $0182);
  AddMsg('LB_SELITEMRANGEEX   ', $0183);
  AddMsg('LB_RESETCONTENT     ', $0184);
  AddMsg('LB_SETSEL           ', $0185);
  AddMsg('LB_SETCURSEL        ', $0186);
  AddMsg('LB_GETSEL           ', $0187);
  AddMsg('LB_GETCURSEL        ', $0188);
  AddMsg('LB_GETTEXT          ', $0189);
  AddMsg('LB_GETTEXTLEN       ', $018A);
  AddMsg('LB_GETCOUNT         ', $018B);
  AddMsg('LB_SELECTSTRING     ', $018C);
  AddMsg('LB_DIR              ', $018D);
  AddMsg('LB_GETTOPINDEX      ', $018E);
  AddMsg('LB_FINDSTRING       ', $018F);
  AddMsg('LB_GETSELCOUNT      ', $0190);
  AddMsg('LB_GETSELITEMS      ', $0191);
  AddMsg('LB_SETTABSTOPS      ', $0192);
  AddMsg('LB_GETHORIZONTALEXTENT ', $0193);
  AddMsg('LB_SETHORIZONTALEXTENT ', $0194);
  AddMsg('LB_SETCOLUMNWIDTH   ', $0195);
  AddMsg('LB_ADDFILE          ', $0196);
  AddMsg('LB_SETTOPINDEX      ', $0197);
  AddMsg('LB_GETITEMRECT      ', $0198);
  AddMsg('LB_GETITEMDATA      ', $0199);
  AddMsg('LB_SETITEMDATA      ', $019A);
  AddMsg('LB_SELITEMRANGE     ', $019B);
  AddMsg('LB_SETANCHORINDEX   ', $019C);
  AddMsg('LB_GETANCHORINDEX   ', $019D);
  AddMsg('LB_SETCARETINDEX    ', $019E);
  AddMsg('LB_GETCARETINDEX    ', $019F);
  AddMsg('LB_SETITEMHEIGHT    ', $01A0);
  AddMsg('LB_GETITEMHEIGHT    ', $01A1);
  AddMsg('LB_FINDSTRINGEXACT  ', $01A2);
  AddMsg('LB_SETLOCALE        ', $01A5);
  AddMsg('LB_GETLOCALE        ', $01A6);
  AddMsg('LB_SETCOUNT         ', $01A7);
  AddMsg('LB_INITSTORAGE      ', $01A8);
  AddMsg('LB_ITEMFROMPOINT    ', $01A9);
  AddMsg('LB_MSGMAX           ', 432);
  AddMsg('CB_GETEDITSEL       ', $0140);
  AddMsg('CB_LIMITTEXT        ', $0141);
  AddMsg('CB_SETEDITSEL       ', $0142);
  AddMsg('CB_ADDSTRING        ', $0143);
  AddMsg('CB_DELETESTRING     ', $0144);
  AddMsg('CB_DIR              ', $0145);
  AddMsg('CB_GETCOUNT         ', $0146);
  AddMsg('CB_GETCURSEL        ', $0147);
  AddMsg('CB_GETLBTEXT        ', $0148);
  AddMsg('CB_GETLBTEXTLEN     ', $0149);
  AddMsg('CB_INSERTSTRING     ', $014A);
  AddMsg('CB_RESETCONTENT     ', $014B);
  AddMsg('CB_FINDSTRING       ', $014C);
  AddMsg('CB_SELECTSTRING     ', $014D);
  AddMsg('CB_SETCURSEL        ', $014E);
  AddMsg('CB_SHOWDROPDOWN     ', $014F);
  AddMsg('CB_GETITEMDATA      ', $0150);
  AddMsg('CB_SETITEMDATA      ', $0151);
  AddMsg('CB_GETDROPPEDCONTROLRECT ', $0152);
  AddMsg('CB_SETITEMHEIGHT    ', $0153);
  AddMsg('CB_GETITEMHEIGHT    ', $0154);
  AddMsg('CB_SETEXTENDEDUI    ', $0155);
  AddMsg('CB_GETEXTENDEDUI    ', $0156);
  AddMsg('CB_GETDROPPEDSTATE  ', $0157);
  AddMsg('CB_FINDSTRINGEXACT  ', $0158);
  AddMsg('CB_SETLOCALE        ', 345);
  AddMsg('CB_GETLOCALE        ', 346);
  AddMsg('CB_GETTOPINDEX      ', 347);
  AddMsg('CB_SETTOPINDEX      ', 348);
  AddMsg('CB_GETHORIZONTALEXTENT ', 349);
  AddMsg('CB_SETHORIZONTALEXTENT ', 350);
  AddMsg('CB_GETDROPPEDWIDTH  ', 351);
  AddMsg('CB_SETDROPPEDWIDTH  ', 352);
  AddMsg('CB_INITSTORAGE      ', 353);
  AddMsg('CB_MSGMAX           ', 354);
  AddMsg('EM_GETSEL           ', $00B0);
  AddMsg('EM_SETSEL           ', $00B1);
  AddMsg('EM_GETRECT          ', $00B2);
  AddMsg('EM_SETRECT          ', $00B3);
  AddMsg('EM_SETRECTNP        ', $00B4);
  AddMsg('EM_SCROLL           ', $00B5);
  AddMsg('EM_LINESCROLL       ', $00B6);
  AddMsg('EM_SCROLLCARET      ', $00B7);
  AddMsg('EM_GETMODIFY        ', $00B8);
  AddMsg('EM_SETMODIFY        ', $00B9);
  AddMsg('EM_GETLINECOUNT     ', $00BA);
  AddMsg('EM_LINEINDEX        ', $00BB);
  AddMsg('EM_SETHANDLE        ', $00BC);
  AddMsg('EM_GETHANDLE        ', $00BD);
  AddMsg('EM_GETTHUMB         ', $00BE);
  AddMsg('EM_LINELENGTH       ', $00C1);
  AddMsg('EM_REPLACESEL       ', $00C2);
  AddMsg('EM_GETLINE          ', $00C4);
  AddMsg('EM_LIMITTEXT        ', $00C5);
  AddMsg('EM_CANUNDO          ', $00C6);
  AddMsg('EM_UNDO             ', $00C7);
  AddMsg('EM_FMTLINES         ', $00C8);
  AddMsg('EM_LINEFROMCHAR     ', $00C9);
  AddMsg('EM_SETTABSTOPS      ', $00CB);
  AddMsg('EM_SETPASSWORDCHAR  ', $00CC);
  AddMsg('EM_EMPTYUNDOBUFFER  ', $00CD);
  AddMsg('EM_GETFIRSTVISIBLELINE ', $00CE);
  AddMsg('EM_SETREADONLY      ', $00CF);
  AddMsg('EM_SETWORDBREAKPROC ', $00D0);
  AddMsg('EM_GETWORDBREAKPROC ', $00D1);
  AddMsg('EM_GETPASSWORDCHAR  ', $00D2);
  AddMsg('EM_SETMARGINS       ', 211);
  AddMsg('EM_GETMARGINS       ', 212);
  AddMsg('EM_GETLIMITTEXT     ', 213);
  AddMsg('EM_POSFROMCHAR      ', 214);
  AddMsg('EM_CHARFROMPOS      ', 215);
  AddMsg('EM_SETIMESTATUS     ', 216);
  AddMsg('EM_GETIMESTATUS     ', 217);
  AddMsg('SBM_SETPOS          ', 224);
  AddMsg('SBM_GETPOS          ', 225);
  AddMsg('SBM_SETRANGE        ', 226);
  AddMsg('SBM_SETRANGEREDRAW  ', 230);
  AddMsg('SBM_GETRANGE        ', 227);
  AddMsg('SBM_ENABLE_ARROWS   ', 228);
  AddMsg('SBM_SETSCROLLINFO   ', 233);
  AddMsg('SBM_GETSCROLLINFO   ', 234);
  AddMsg('CM_ACTIVATE         ', CM_BASE + 0);
  AddMsg('CM_DEACTIVATE       ', CM_BASE + 1);
  AddMsg('CM_GOTFOCUS         ', CM_BASE + 2);
  AddMsg('CM_LOSTFOCUS        ', CM_BASE + 3);
  AddMsg('CM_CANCELMODE       ', CM_BASE + 4);
  AddMsg('CM_DIALOGKEY        ', CM_BASE + 5);
  AddMsg('CM_DIALOGCHAR       ', CM_BASE + 6);
  AddMsg('CM_FOCUSCHANGED     ', CM_BASE + 7);
  AddMsg('CM_PARENTFONTCHANGED ', CM_BASE + 8);
  AddMsg('CM_PARENTCOLORCHANGED ', CM_BASE + 9);
  AddMsg('CM_HITTEST          ', CM_BASE + 10);
  AddMsg('CM_VISIBLECHANGED   ', CM_BASE + 11);
  AddMsg('CM_ENABLEDCHANGED   ', CM_BASE + 12);
  AddMsg('CM_COLORCHANGED     ', CM_BASE + 13);
  AddMsg('CM_FONTCHANGED      ', CM_BASE + 14);
  AddMsg('CM_CURSORCHANGED    ', CM_BASE + 15);
  AddMsg('CM_CTL3DCHANGED     ', CM_BASE + 16);
  AddMsg('CM_PARENTCTL3DCHANGED ', CM_BASE + 17);
  AddMsg('CM_TEXTCHANGED      ', CM_BASE + 18);
  AddMsg('CM_MOUSEENTER       ', CM_BASE + 19);
  AddMsg('CM_MOUSELEAVE       ', CM_BASE + 20);
  AddMsg('CM_MENUCHANGED      ', CM_BASE + 21);
  AddMsg('CM_APPKEYDOWN       ', CM_BASE + 22);
  AddMsg('CM_APPSYSCOMMAND    ', CM_BASE + 23);
  AddMsg('CM_BUTTONPRESSED    ', CM_BASE + 24);
  AddMsg('CM_SHOWINGCHANGED   ', CM_BASE + 25);
  AddMsg('CM_ENTER            ', CM_BASE + 26);
  AddMsg('CM_EXIT             ', CM_BASE + 27);
  AddMsg('CM_DESIGNHITTEST    ', CM_BASE + 28);
  AddMsg('CM_ICONCHANGED      ', CM_BASE + 29);
  AddMsg('CM_WANTSPECIALKEY   ', CM_BASE + 30);
  AddMsg('CM_INVOKEHELP       ', CM_BASE + 31);
  AddMsg('CM_WINDOWHOOK       ', CM_BASE + 32);
  AddMsg('CM_RELEASE          ', CM_BASE + 33);
  AddMsg('CM_SHOWHINTCHANGED  ', CM_BASE + 34);
  AddMsg('CM_PARENTSHOWHINTCHANGED ', CM_BASE + 35);
  AddMsg('CM_SYSCOLORCHANGE   ', CM_BASE + 36);
  AddMsg('CM_WININICHANGE     ', CM_BASE + 37);
  AddMsg('CM_FONTCHANGE       ', CM_BASE + 38);
  AddMsg('CM_TIMECHANGE       ', CM_BASE + 39);
  AddMsg('CM_TABSTOPCHANGED   ', CM_BASE + 40);
  AddMsg('CM_UIACTIVATE       ', CM_BASE + 41);
  AddMsg('CM_UIDEACTIVATE     ', CM_BASE + 42);
  AddMsg('CM_DOCWINDOWACTIVATE ', CM_BASE + 43);
  AddMsg('CM_CONTROLLISTCHANGE ', CM_BASE + 44);
  AddMsg('CM_GETDATALINK      ', CM_BASE + 45);
  AddMsg('CM_CHILDKEY         ', CM_BASE + 46);
  AddMsg('CM_DRAG             ', CM_BASE + 47);
  AddMsg('CM_HINTSHOW         ', CM_BASE + 48);
  AddMsg('CM_DIALOGHANDLE     ', CM_BASE + 49);
  AddMsg('CM_ISTOOLCONTROL    ', CM_BASE + 50);
  AddMsg('CM_RECREATEWND      ', CM_BASE + 51);
  AddMsg('CM_INVALIDATE       ', CM_BASE + 52);
  AddMsg('CM_SYSFONTCHANGED   ', CM_BASE + 53);
  AddMsg('CM_CONTROLCHANGE    ', CM_BASE + 54);
  AddMsg('CM_CHANGED          ', CM_BASE + 55);
  AddMsg('CM_DOCKCLIENT       ', CM_BASE + 56);
  AddMsg('CM_UNDOCKCLIENT     ', CM_BASE + 57);
  AddMsg('CM_FLOAT            ', CM_BASE + 58);
  AddMsg('CM_BORDERCHANGED    ', CM_BASE + 59);
  AddMsg('CM_BIDIMODECHANGED  ', CM_BASE + 60);
  AddMsg('CM_PARENTBIDIMODECHANGED ', CM_BASE + 61);
  AddMsg('CM_ALLCHILDRENFLIPPED ', CM_BASE + 62);
  AddMsg('CM_ACTIONUPDATE     ', CM_BASE + 63);
  AddMsg('CM_ACTIONEXECUTE    ', CM_BASE + 64);
  AddMsg('CM_HINTSHOWPAUSE    ', CM_BASE + 65);
  AddMsg('CM_DOCKNOTIFICATION ', CM_BASE + 66);
  AddMsg('CM_MOUSEWHEEL       ', CM_BASE + 67);
  AddMsg('CN_BASE             ', $BC00);
  AddMsg('CN_CHARTOITEM       ', CN_BASE + WM_CHARTOITEM);
  AddMsg('CN_COMMAND          ', CN_BASE + WM_COMMAND);
  AddMsg('CN_COMPAREITEM      ', CN_BASE + WM_COMPAREITEM);
  AddMsg('CN_CTLCOLORBTN      ', CN_BASE + WM_CTLCOLORBTN);
  AddMsg('CN_CTLCOLORDLG      ', CN_BASE + WM_CTLCOLORDLG);
  AddMsg('CN_CTLCOLOREDIT     ', CN_BASE + WM_CTLCOLOREDIT);
  AddMsg('CN_CTLCOLORLISTBOX  ', CN_BASE + WM_CTLCOLORLISTBOX);
  AddMsg('CN_CTLCOLORMSGBOX   ', CN_BASE + WM_CTLCOLORMSGBOX);
  AddMsg('CN_CTLCOLORSCROLLBAR ', CN_BASE + WM_CTLCOLORSCROLLBAR);
  AddMsg('CN_CTLCOLORSTATIC   ', CN_BASE + WM_CTLCOLORSTATIC);
  AddMsg('CN_DELETEITEM       ', CN_BASE + WM_DELETEITEM);
  AddMsg('CN_DRAWITEM         ', CN_BASE + WM_DRAWITEM);
  AddMsg('CN_HSCROLL          ', CN_BASE + WM_HSCROLL);
  AddMsg('CN_MEASUREITEM      ', CN_BASE + WM_MEASUREITEM);
  AddMsg('CN_PARENTNOTIFY     ', CN_BASE + WM_PARENTNOTIFY);
  AddMsg('CN_VKEYTOITEM       ', CN_BASE + WM_VKEYTOITEM);
  AddMsg('CN_VSCROLL          ', CN_BASE + WM_VSCROLL);
  AddMsg('CN_KEYDOWN          ', CN_BASE + WM_KEYDOWN);
  AddMsg('CN_KEYUP            ', CN_BASE + WM_KEYUP);
  AddMsg('CN_CHAR             ', CN_BASE + WM_CHAR);
  AddMsg('CN_SYSKEYDOWN       ', CN_BASE + WM_SYSKEYDOWN);
  AddMsg('CN_SYSCHAR          ', CN_BASE + WM_SYSCHAR);
  AddMsg('CN_NOTIFY           ', CN_BASE + WM_NOTIFY);
  MsgList.Sort(SortMsgListProc);
  for I := 0 to MsgList.Count - 2 do
    if LongRec(MsgList[I]).Hi = LongRec(MsgList[I + 1]).Hi then
      raise EMessageDictError.Create(
        'TMessageDict duplicate message number $' +
          IntToHex(LongRec(MsgList[I]).Hi, 4));
end;

end.
